==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaPlayer_shell.h <==
#ifndef QMEDIAPLAYER_SHELL_H
#define QMEDIAPLAYER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaplayer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qabstractvideosurface.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qmediacontent.h>
#include <QtMultimedia/qmediaplaylist.h>
#include <QtMultimedia/qmediaservice.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtMultimediaWidgets/qvideowidget.h>
#include <QtNetwork/qnetworkconfiguration.h>
#include <QtJambi/RegistryAPI>


class QMediaPlayer_shell : public QMediaPlayer, public QtJambiShellInterface
{
public:
    QMediaPlayer_shell(QObject* parent0 = nullptr, QMediaPlayer::Flags flags1 = QMediaPlayer::Flags());
    ~QMediaPlayer_shell() override;

    QMultimedia::AvailabilityStatus availability() const override;
    bool bind(QObject* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isAvailable() const override;
    QMediaService* service() const override;
    void timerEvent(QTimerEvent* event0) override;
    void unbind(QObject* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaPlayer_access : public QMediaPlayer
{
    jint __qt_availability(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_bind_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_unbind_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QMEDIAPLAYER_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaPlayer_shell.h <==
#ifndef QMEDIAPLAYER_SHELL_H
#define QMEDIAPLAYER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaplayer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qabstractvideosurface.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qmediacontent.h>
#include <QtMultimedia/qmediaplaylist.h>
#include <QtMultimedia/qmediaservice.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtMultimediaWidgets/qvideowidget.h>
#include <QtNetwork/qnetworkconfiguration.h>
#include <QtJambi/RegistryAPI>


class QMediaPlayer_shell : public QMediaPlayer, public QtJambiShellInterface
{
public:
    QMediaPlayer_shell(QObject* parent0 = nullptr, QMediaPlayer::Flags flags1 = QMediaPlayer::Flags());
    ~QMediaPlayer_shell() override;

    QMultimedia::AvailabilityStatus availability() const override;
    bool bind(QObject* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isAvailable() const override;
    QMediaService* service() const override;
    void timerEvent(QTimerEvent* event0) override;
    void unbind(QObject* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaPlayer_access : public QMediaPlayer
{
    jint __qt_availability_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_bind_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_unbind_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QMEDIAPLAYER_SHELL_H
